@@ -46,6 +46,16 @@ if hasattr(sys, "implementation"):
             r"\1.\2",
             sys.implementation.cache_tag,
         )
+    elif implementation_name == "pyston":
+        # Pyston reports the CPython version as sys.implementation.version,
+        # so we need to discover the Pyston version from the cache_tag
+        import re
+
+        implementation_version = re.sub(
+            r"pyston-(\d)(\d+)",
+            r"\1.\2",
+            sys.implementation.cache_tag,
+        )
     else:
         implementation_version = format_full_version(sys.implementation.version)
 else:
@@ -521,6 +531,7 @@ def get_operating_system_and_architecture():
             "minor": int(version[1]),
             "simulator": ios_ver.is_simulator,
         }
+        [_version, architecture, _platform] = version_arch.split("-")
     elif operating_system == "emscripten":
         pyodide_abi_version = sysconfig.get_config_var("PYODIDE_ABI_VERSION")
         if not pyodide_abi_version:
