@@ -4,13 +4,12 @@ use assert_fs::prelude::*;
 use indoc::indoc;
 use insta::assert_snapshot;
 
-use crate::common::TestContext;
-use crate::common::uv_snapshot;
+use uv_test::uv_snapshot;
 
 // Print the version
 #[test]
 fn version_get() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -48,7 +47,7 @@ fn version_get() -> Result<()> {
 // Print the version (json format)
 #[test]
 fn version_get_json() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -91,7 +90,7 @@ fn version_get_json() -> Result<()> {
 // Print the version (--short)
 #[test]
 fn version_get_short() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -131,7 +130,7 @@ fn version_get_short() -> Result<()> {
 // Set the version
 #[test]
 fn version_set_value() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -173,7 +172,7 @@ requires-python = ">=3.12"
 // Set the version (--short)
 #[test]
 fn version_set_value_short() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -216,7 +215,7 @@ requires-python = ">=3.12"
 // Bump patch version
 #[test]
 fn version_bump_patch() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -256,7 +255,7 @@ requires-python = ">=3.12"
 
 #[test]
 fn version_bump_patch_value() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -296,7 +295,7 @@ requires-python = ">=3.12"
 
 #[test]
 fn version_bump_minor_value() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -336,7 +335,7 @@ requires-python = ">=3.12"
 
 #[test]
 fn version_bump_major_value() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -377,7 +376,7 @@ requires-python = ">=3.12"
 // Bump patch version (--short)
 #[test]
 fn version_bump_patch_short() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -418,7 +417,7 @@ requires-python = ">=3.12"
 
 #[test]
 fn version_bump_patch_value_must_increase() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -457,7 +456,7 @@ requires-python = ">=3.12"
 /// Preserve comments immediately preceding the version when bumping
 #[test]
 fn version_bump_preserves_preceding_comments() -> Result<()> {
-    let context: TestContext = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -502,7 +501,7 @@ fn version_bump_preserves_preceding_comments() -> Result<()> {
 // Bump minor version
 #[test]
 fn version_bump_minor() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -543,7 +542,7 @@ requires-python = ">=3.12"
 // bump major version
 #[test]
 fn version_major_version() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -584,7 +583,7 @@ requires-python = ">=3.12"
 // Bump patch but the input version is missing a component
 #[test]
 fn version_patch_uncompleted() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -625,7 +624,7 @@ requires-python = ">=3.12"
 // Bump minor but the input version is missing a component
 #[test]
 fn version_minor_uncompleted() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -666,7 +665,7 @@ requires-python = ">=3.12"
 // Bump major but the input version is missing a component
 #[test]
 fn version_major_uncompleted() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -707,7 +706,7 @@ requires-python = ">=3.12"
 // Bump major but the input version is .dev
 #[test]
 fn version_major_dev() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -748,7 +747,7 @@ requires-python = ">=3.12"
 // Bump major but the input version is a complex mess
 #[test]
 fn version_major_complex_mess() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -792,7 +791,7 @@ requires-python = ">=3.12"
 // now it fails for a dozen reasons!
 #[test]
 fn many_bump_complex() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -838,7 +837,7 @@ requires-python = ">=3.12"
 // --bump stable
 #[test]
 fn bump_stable() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -879,7 +878,7 @@ requires-python = ">=3.12"
 // --bump alpha
 #[test]
 fn bump_alpha() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -920,7 +919,7 @@ requires-python = ">=3.12"
 // --bump beta
 #[test]
 fn bump_beta() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -960,7 +959,7 @@ requires-python = ">=3.12"
 
 #[test]
 fn bump_beta_with_value_existing() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -1000,7 +999,7 @@ requires-python = ">=3.12"
 
 #[test]
 fn bump_beta_with_value_new() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -1042,7 +1041,7 @@ requires-python = ">=3.12"
 // --bump rc
 #[test]
 fn bump_rc() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -1083,7 +1082,7 @@ requires-python = ">=3.12"
 // --bump post
 #[test]
 fn bump_post() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -1123,7 +1122,7 @@ requires-python = ">=3.12"
 
 #[test]
 fn bump_post_with_value_clears_dev() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -1164,7 +1163,7 @@ requires-python = ">=3.12"
 // --bump dev
 #[test]
 fn bump_dev() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -1204,7 +1203,7 @@ requires-python = ">=3.12"
 
 #[test]
 fn bump_dev_with_value() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -1244,7 +1243,7 @@ requires-python = ">=3.12"
 
 #[test]
 fn bump_patch_and_dev_value() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -1285,7 +1284,7 @@ requires-python = ">=3.12"
 
 #[test]
 fn bump_patch_and_dev_explicit_values_sorted() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -1327,7 +1326,7 @@ requires-python = ">=3.12"
 // Bump major but the input version is .post
 #[test]
 fn version_major_post() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -1367,7 +1366,7 @@ requires-python = ">=3.12"
 
 #[test]
 fn bump_stable_with_value_fails() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -1393,7 +1392,7 @@ requires-python = ">=3.12"
 
 #[test]
 fn bump_empty_value_fails() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -1419,7 +1418,7 @@ requires-python = ">=3.12"
 
 #[test]
 fn bump_invalid_numeric_value_fails() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -1446,7 +1445,7 @@ requires-python = ">=3.12"
 // --bump stable but it decreases the version
 #[test]
 fn bump_decrease_stable() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -1473,7 +1472,7 @@ requires-python = ">=3.12"
 // --bump alpha but it decreases the version by reverting beta
 #[test]
 fn bump_decrease_alpha_beta() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -1500,7 +1499,7 @@ requires-python = ">=3.12"
 // --bump alpha but it decreases the version from a stable
 #[test]
 fn bump_decrease_alpha_stable() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -1527,7 +1526,7 @@ requires-python = ">=3.12"
 // --bump dev but it decreases the version from a stable
 #[test]
 fn bump_decrease_dev_stable() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -1554,7 +1553,7 @@ requires-python = ">=3.12"
 // --bump dev but it decreases the version from a pre-release
 #[test]
 fn bump_decrease_dev_prerelease() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -1581,7 +1580,7 @@ requires-python = ">=3.12"
 // --bump major twice
 #[test]
 fn bump_double_major() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -1609,7 +1608,7 @@ requires-python = ">=3.12"
 // --bump alpha twice
 #[test]
 fn bump_double_alpha() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -1637,7 +1636,7 @@ requires-python = ">=3.12"
 // --bump stable --bump major
 #[test]
 fn bump_stable_major() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -1665,7 +1664,7 @@ requires-python = ">=3.12"
 // --bump major --bump alpha
 #[test]
 fn bump_alpha_major() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -1695,7 +1694,7 @@ requires-python = ">=3.12"
 // --bump major --bump minor
 #[test]
 fn bump_minor_major() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -1725,7 +1724,7 @@ requires-python = ">=3.12"
 // --bump alpha --bump dev
 #[test]
 fn bump_alpha_dev() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -1753,7 +1752,7 @@ requires-python = ">=3.12"
 // --bump major --bump dev
 #[test]
 fn bump_dev_major() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -1783,7 +1782,7 @@ requires-python = ">=3.12"
 // --bump major --bump post
 #[test]
 fn bump_post_major() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -1811,7 +1810,7 @@ requires-python = ">=3.12"
 // Set version --dry-run
 #[test]
 fn version_set_dry() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -1851,7 +1850,7 @@ requires-python = ">=3.12"
 // Bump version --dry-run
 #[test]
 fn version_major_dry() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -1891,7 +1890,7 @@ requires-python = ">=3.12"
 // Set version invalid
 #[test]
 fn version_set_invalid() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -1930,7 +1929,7 @@ requires-python = ">=3.12"
 // forget --bump but pass a valid bump name
 #[test]
 fn version_missing_bump() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -1969,7 +1968,7 @@ requires-python = ">=3.12"
 // Dynamic version should error on read
 #[test]
 fn version_get_dynamic() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -2007,7 +2006,7 @@ fn version_get_dynamic() -> Result<()> {
 // Dynamic version should error on write
 #[test]
 fn version_set_dynamic() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -2047,7 +2046,7 @@ fn version_set_dynamic() -> Result<()> {
 /// (In this case, because tool.uv.managed = false)
 #[test]
 fn version_get_fallback_unmanaged() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -2089,7 +2088,7 @@ fn version_get_fallback_unmanaged() -> Result<()> {
 // version_get_fallback with `--short`
 #[test]
 fn version_get_fallback_unmanaged_short() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -2157,7 +2156,7 @@ fn git_version_info_expected() -> bool {
 // and --project was passed explicitly.
 #[test]
 fn version_get_fallback_unmanaged_strict() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -2201,7 +2200,7 @@ fn version_get_fallback_unmanaged_strict() -> Result<()> {
 // and --project was passed explicitly.
 #[test]
 fn version_get_fallback_missing_strict() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     uv_snapshot!(context.filters(), context.version()
         .arg("--project").arg("."), @"
@@ -2219,7 +2218,7 @@ fn version_get_fallback_missing_strict() -> Result<()> {
 /// Should error with hint if pyproject.toml is missing in normal mode
 #[test]
 fn version_get_missing_with_hint() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     uv_snapshot!(context.filters(), context.version(), @"
     success: false
@@ -2239,7 +2238,7 @@ fn version_get_missing_with_hint() -> Result<()> {
 // (also setup a honeypot project and make sure it's not used)
 #[test]
 fn self_version() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -2276,7 +2275,7 @@ fn self_version() -> Result<()> {
 // (also setup a honeypot project and make sure it's not used)
 #[test]
 fn self_version_short() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -2322,7 +2321,7 @@ fn self_version_short() -> Result<()> {
 // (also setup a honeypot project and make sure it's not used)
 #[test]
 fn self_version_json() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -2407,7 +2406,7 @@ fn self_version_json() -> Result<()> {
 // Ensure that the global `--project` option is respected.
 #[test]
 fn version_get_workspace() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -2491,7 +2490,7 @@ fn version_get_workspace() -> Result<()> {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn version_set_workspace() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let workspace = context.temp_dir.child("pyproject.toml");
     workspace.write_str(indoc! {r#"
@@ -2833,7 +2832,7 @@ fn version_set_workspace() -> Result<()> {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn version_set_evil_constraints() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let workspace = context.temp_dir.child("pyproject.toml");
     workspace.write_str(indoc! {r#"
@@ -3077,7 +3076,7 @@ fn version_set_evil_constraints() -> Result<()> {
 #[test]
 fn virtual_empty() -> Result<()> {
     // testing how `uv version` reacts to a pyproject with no `[project]` and nothing useful to it
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(indoc! {r#"
@@ -3141,7 +3140,7 @@ fn add_virtual_dependency_group() -> Result<()> {
     // testing basic `uv version` functionality
     // when the pyproject.toml is fully virtual (no `[project]`)
     // But at least has some dependency-group tables (shouldn't matter to this command)
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(indoc! {r#"
@@ -3210,7 +3209,7 @@ fn add_virtual_dependency_group() -> Result<()> {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn version_extras() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
